@@ -340,9 +340,12 @@ dot_graph.measurement_model <-
   as.data.frame(mm) -> mmodel
 
   hocs <- model$higher_order_composite
-  hocs
+
   a_model <- list(measurement_model = model,
                 mmMatrix = mm,
+                smMatrix = matrix(rep(unique(mmodel$construct),2),
+                                  ncol = 2,
+                                  nrow = length(unique(mmodel$construct))),
                 outer_weights = matrix(c(1), # add only 1s
                                        ncol = length(unique(mmodel$construct) ),
                                        dimnames = list(unique(mmodel$measurement),
@@ -358,11 +361,13 @@ dot_graph.measurement_model <-
                 constructs = unique(mmodel$construct),
                 mmVariables = unique(mmodel$measurement)
   )
-
+  if (length(hocs) > 0) {
+    a_model$hoc <- TRUE
+  }
   class(a_model) <- "pls_model"
 
 
-  # adjust themes to correct for aritifical information
+  # adjust themes to correct for artifical information
   thm$mm.edge.width_multiplier <- 1
   thm$mm.edge.label.show <- FALSE
   dot_graph(a_model, title = title, theme = thm, measurement_only = TRUE)
@@ -976,7 +981,8 @@ get_sm_node_shape <- function(model, construct, theme) {
                    "B" = paste0(", shape = ", theme$construct.compositeB.shape),
                    "A" = paste0(", shape = ", theme$construct.compositeA.shape),
                    "HOCA" = paste0(", shape = ", theme$construct.compositeA.shape),
-                   "HOCB" = paste0(", shape = ", theme$construct.compositeB.shape)
+                   "HOCB" = paste0(", shape = ", theme$construct.compositeB.shape),
+                   "UNIT" = paste0(", shape = ", theme$construct.compositeB.shape)
   )
   return(result)
 }
@@ -1206,7 +1212,13 @@ dot_component_mm <- function(model, theme) {
                                 "// ---------------------\n"))
 
   # we use mmMatrix because model$constructs does not contain HOCs
-  mm_count <- length(unique(model$mmMatrix[,1 ]))
+  if (is.null(model$hoc)) {
+    mm_count <- length(intersect(unique(model$smMatrix),unique(model$mmMatrix[,1 ])))
+  } else {
+    mm_count <- length(intersect(unique(c(model$smMatrix, model$first_stage_model$smMatrix)),unique(model$mmMatrix[,1 ])))
+  }
+
+
   for (i in 1:mm_count) {
     sub_component <- dot_subcomponent_mm(i, model, theme)
     sub_components_mm <- c(sub_components_mm, sub_component)
@@ -1273,19 +1285,13 @@ dot_subcomponent_mm <- function(index, model, theme) {
 #'
 #' @param model the model to use
 extract_mm_coding <- function(model) {
-  construct_names <- c()
-  construct_types <- c()
-
   # iterate over all constructs in the mmMatrix
-  for (construct in unique(model$mmMatrix[,1 ])) {
-    construct_names <- c(construct_names, construct)
-    construct_types <- c(construct_types, get_construct_type(model, construct))
-  }
+  constructs <- constructs_in_model(model)
 
   # create output matrix
-  mm_coding <- matrix(nrow = length(construct_names),
+  mm_coding <- matrix(nrow = length(constructs$construct_names),
                       ncol = 2,
-                      data = c(construct_names, construct_types))
+                      data = c(constructs$construct_names, constructs$construct_types))
   colnames(mm_coding) <- c("name", "type")
   return(mm_coding)
 }
@@ -1348,7 +1354,8 @@ get_mm_node_shape <- function(model, construct, theme) {
                    "B" = paste0(", shape = ", theme$manifest.compositeB.shape),
                    "A" = paste0(", shape = ", theme$manifest.compositeA.shape),
                    "HOCA" = paste0(", shape = ", theme$manifest.compositeA.shape),
-                   "HOCB" = paste0(", shape = ", theme$manifest.compositeB.shape)
+                   "HOCB" = paste0(", shape = ", theme$manifest.compositeB.shape),
+                   "UNIT" = paste0(", shape = ", theme$construct.compositeB.shape)
   )
   return(result)
 }
@@ -1373,7 +1380,7 @@ get_mm_edge_style <- function(theme, construct_type, flip = FALSE){
   if (construct_type == "A" || construct_type == "HOCA") {
     direction <- theme$construct.compositeA.arrow
   }
-  if (construct_type == "B" || construct_type == "HOCB") {
+  if (construct_type == "B" || construct_type == "HOCB" || construct_type == "UNIT") {
     direction <- theme$construct.compositeB.arrow
   }
 
@@ -1471,7 +1478,7 @@ use_construct_weights <- function(theme, construct_type) {
   if (construct_type == "A" || construct_type == "HOCA") {
     return(theme$construct.compositeA.use_weights)
   }
-  if (construct_type == "B" || construct_type == "HOCB") {
+  if (construct_type == "B" || construct_type == "HOCB" || construct_type == "UNIT") {
     return(theme$construct.compositeB.use_weights)
   }
 
@@ -1515,7 +1522,7 @@ extract_mm_edges <- function(index, model, theme, weights = 1000) {
     construct_variable = mm_matrix_subset[i, 1]
 
     use_weights <- use_construct_weights(theme,
-                                         get_construct_type(model, construct_variable))
+                                                  get_construct_type(model, construct_variable))
 
 
     # If interaction variable, we skip
