@@ -16,9 +16,9 @@ test_that("pvalr works", {
   testthat::expect_equal(seminr:::pvalr(0.0001), "< 0.001")
 
   testthat::expect_equal(seminr:::pvalr(0.326, digits = 2), "= 0.33")
-  testthat::expect_equal(seminr:::pvalr(0.1, html = T), "= 0.100")
+  testthat::expect_equal(seminr:::pvalr(0.1, html = TRUE), "= 0.100")
   testthat::expect_equal(seminr:::pvalr(0.01, digits = 5), "= 0.01000")
-  testthat::expect_equal(seminr:::pvalr(0.0001, html = T), "&lt; 0.001")
+  testthat::expect_equal(seminr:::pvalr(0.0001, html = TRUE), "&lt; 0.001")
 })
 
 
@@ -29,7 +29,7 @@ test_that("psignr works", {
   testthat::expect_equal(seminr:::psignr(0.001), "**")
   testthat::expect_equal(seminr:::psignr(0.0001), "***")
 
-  testthat::expect_equal(seminr:::psignr(0.1, html = T), "")
-  testthat::expect_equal(seminr:::psignr(0.01, html = T), "*")
-  testthat::expect_equal(seminr:::psignr(0.0001, html = T), "***")
+  testthat::expect_equal(seminr:::psignr(0.1, html = TRUE), "")
+  testthat::expect_equal(seminr:::psignr(0.01, html = TRUE), "*")
+  testthat::expect_equal(seminr:::psignr(0.0001, html = TRUE), "***")
 })
